==> jbossws-spi-2.3.1.Final-sources.jar: org/jboss/wsf/spi/metadata/config/ClientConfig.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wsf.spi.metadata.config;

import java.util.List;
import java.util.Map;

import org.jboss.wsf.spi.metadata.j2ee.serviceref.UnifiedHandlerChainMetaData;

/** 
 * A JBossWS client configuration 
 *
 * @author alessio.soldano@jboss.com
 * @since 29-Apr-2011
 */
public class ClientConfig extends AbstractCommonConfig
{
   public static final String STANDARD_CLIENT_CONFIG = "Standard-Client-Config";

   public ClientConfig(String configName, List<UnifiedHandlerChainMetaData> preHandlerChains,
         List<UnifiedHandlerChainMetaData> postHandlerChains, Map<String, String> properties,
         Map<String, Feature> features)
   {
      super(configName, preHandlerChains, postHandlerChains, properties, features);
   }
   
   public ClientConfig(ClientConfig base, ClientConfig addon) {
      super(base, addon);
   }
}

==> jbossws-spi-3.4.0.Final-sources.jar: org/jboss/wsf/spi/metadata/config/ClientConfig.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wsf.spi.metadata.config;

import java.util.List;
import java.util.Map;

import org.jboss.wsf.spi.metadata.j2ee.serviceref.UnifiedHandlerChainMetaData;

import javax.net.ssl.SSLContext;

/** 
 * A JBossWS client configuration 
 *
 * @author alessio.soldano@jboss.com
 * @since 29-Apr-2011
 */
public class ClientConfig extends AbstractCommonConfig
{
   public static final String STANDARD_CLIENT_CONFIG = "Standard-Client-Config";
   public static final String DEFAULT_CLIENT_CONFIG_FILE = "jaxws-client-config.xml";
   public static final String WILDLFY_CLIENT_CONFIG_FILE = "WildFly-Client-Config";

   public ClientConfig(String configName, List<UnifiedHandlerChainMetaData> preHandlerChains,
         List<UnifiedHandlerChainMetaData> postHandlerChains, Map<String, String> properties,
         Map<String, Feature> features)
   {
      super(configName, preHandlerChains, postHandlerChains, properties, features);
   }
   
   public ClientConfig(ClientConfig base, ClientConfig addon) {
      super(base, addon);
   }
}
